var _columnWidth = require('./columnWidth');

var _columnWidth2 = _interopRequireDefault(_columnWidth);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var mockProps = { xs: -1, sm: 2, md: 0, lg: 6 };

describe('percentage', function () {
  test('should generate a percentage based on collumn size', function () {
    expect((0, _columnWidth.percentage)(mockProps, 'lg')).toEqual(50);
    expect((0, _columnWidth.percentage)(mockProps, 'md')).toEqual(0);
    expect((0, _columnWidth.percentage)(mockProps, 'sm')).toEqual(16.666666666666664);
  });

  test('should normalise negative numbers', function () {
    expect((0, _columnWidth.percentage)(mockProps, 'xs')).toEqual(8.333333333333332);
  });
});

describe('isHidden', function () {
  test('should return hidden if a given breakpoint is explicitly "0" or "hidden"', function () {
    expect((0, _columnWidth.isHidden)({ xs: 0 }, 'xs')).toEqual(true);
    expect((0, _columnWidth.isHidden)({ xs: 'hidden' }, 'xs')).toEqual(true);
    expect((0, _columnWidth.isHidden)({ xs: undefined }, 'xs')).toEqual(false);
    expect((0, _columnWidth.isHidden)({ xs: 12 }, 'xs')).toEqual(false);
  });
});

describe('isAuto', function () {
  test('should return flex: 1 if a given property is explicitly "auto" if a given breakpoint is explicitly set to auto', function () {
    var autoGrowMockProps = { xs: -1, sm: 2, md: 'auto', lg: 6 };
    var width = (0, _columnWidth2['default'])(autoGrowMockProps, 'md').join('');
    expect((0, _columnWidth.isAuto)({ xs: 'auto' }, 'xs')).toEqual(true);
    expect(width).toContain('flex: 1');
  });
});

describe('display', function () {
  test('should return block if no display is set', function () {
    var value = (0, _columnWidth.display)(mockProps, 'lg').join('');
    expect(value).toContain('display: block');
  });

  test('should return display prop if set as string', function () {
    var value = (0, _columnWidth.display)({ sm: 1, display: 'flex' }, 'sm').join('');
    expect(value).toContain('display: flex');
  });

  test('should return null prop if display is set to current breakpoint', function () {
    var value = (0, _columnWidth.display)({ sm: 1, display: { sm: 'flex' } }, 'sm');
    expect(value).toEqual(null);
  });

  test('should return display prop if display does not have matching breakpoint', function () {
    var value = (0, _columnWidth.display)({ sm: 1, display: { md: 'flex' } }, 'sm').join('');
    expect(value).toContain('display: block');
  });
});

describe('columnWidth', function () {
  test('should generate column width css', function () {
    var width = (0, _columnWidth2['default'])(mockProps, 'sm').join('');
    expect(width).toContain('flex-basis: 16.666666666666664%;');
    expect(width).toContain('max-width: 16.666666666666664%;');
  });

  test('should return nothing if breakpoint does not exist', function () {
    var width = (0, _columnWidth2['default'])(mockProps, 'xl');
    expect(width).toEqual(null);
  });

  test('should not return display:block', function () {
    var displayProps = { xs: 1, display: 'flex' };
    var width = (0, _columnWidth2['default'])(displayProps, 'xs');
    expect(width).not.toContain('display: block');
  });

  test('should only return display:block if display has not alreayd been set', function () {
    var displayProps = { xs: 1 };
    var width = (0, _columnWidth2['default'])(displayProps, 'xs');
    expect(width).toContain('display: block');
  });

  test('should return "display:none" if breakpoint is explicity set to 0', function () {
    var width = (0, _columnWidth2['default'])(mockProps, 'md').join('');
    expect(width).toContain('display: none');
  });

  test('should return "display:none" if breakpoint is explicity set to "hidden"', function () {
    var hiddenMockProps = { xs: -1, sm: 2, md: 'hidden', lg: 6 };
    var width = (0, _columnWidth2['default'])(hiddenMockProps, 'md').join('');
    expect(width).toContain('display: none');
  });

  test('should return a fixed column', function () {
    var hiddenMockProps = { xs: 12, sm: 5, md: 6, lg: '390px' };
    var width = (0, _columnWidth2['default'])(hiddenMockProps, 'lg').join('');
    expect(width).toContain('max-width: 390px;');
  });

  test('should return a fixed column with sibling responsive', function () {
    var hiddenMockProps = { xs: 12, sm: 5, md: 6, lg: 'calc(100% - 390px)' };
    var width = (0, _columnWidth2['default'])(hiddenMockProps, 'lg').join('');
    expect(width).toContain('calc(100% - 390px);');
  });
});